@@ -8,7 +8,7 @@ var Table = require('easy-table');
 var cli_debug = require('debug')('3scale-cli');
 
 exports.debug = function(obj){
-  return require('debug')(obj.name)(obj.msg,obj.data)
+  return require('debug')(obj.name)(obj.msg,obj.data || '')
 }
 
 exports.success = success = function(options){
