@@ -23,14 +23,20 @@ exports.createApplicationPlan = function(service_id,name){
       "state":"published"
     }
   };
+
+  cli.debug({name: '3scale-cli:app-plan:create', msg: 'API call URL: %o', data: url})
+  cli.debug({name: '3scale-cli:app-plan:create', msg: 'data sent %o: ', data: options.form});
+
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
     var body = JSON.parse(r[0].body);
     if (res.statusCode >= 300) {
-      cli.error({message:"ERROR encountered creating Application Plan:  " + JSON.stringify(body.errors || body.status)});
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.status));
+      cli.error({message:"ERROR encountered creating Application Plan:  " + JSON.stringify(body.errors || body.error || body.status)});
+      cli.debug({name: '3scale-cli:app-plan:create', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.errorr || body.status)})
+      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
     } else {
+      cli.debug({name: '3scale-cli:app-plan:create', msg: 'result: %o' , data: body.application_plan})
       return body.application_plan;
     }
   });
@@ -46,14 +52,19 @@ exports.getApplicationPlanById = function(service_id, plan_id){
     }
   };
 
+  cli.debug({name: '3scale-cli:app-plan:getApplicationPlanById', msg: 'API call URL: %o', data: url})
+  cli.debug({name: '3scale-cli:app-plan:getApplicationPlanById', msg: 'data sent %o: ', data: options.form});
+
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
     var body = JSON.parse(r[0].body);
     if (res.statusCode >= 300) {
-      cli.error({message:"ERROR encountered: " + JSON.stringify(body.errors || body.status)});
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.status));
+      cli.error({message:"ERROR encountered: " + JSON.stringify(body.errors || body.error || body.status)});
+      cli.debug({name: '3scale-cli:app-plan:getApplicationPlanById', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)})
+      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
     } else {
+      cli.debug({name: '3scale-cli:app-plan:getApplicationPlanById', msg: 'result: %o' , data: body.application_plan})
       return body.application_plan
     }
   });
@@ -70,18 +81,24 @@ exports.getApplicationPlanByName = function(service_id, plan_name){
     }
   };
 
+  cli.debug({name: '3scale-cli:app-plan:getApplicationPlanByName', msg: 'API call URL: %o', data: url});
+  cli.debug({name: '3scale-cli:app-plan:getApplicationPlanByName', msg: 'data sent %o: ', data: options.form});
+
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
     var body = JSON.parse(r[0].body);
     if (res.statusCode >= 300) {
-      cli.error({message:"ERROR encountered: " + JSON.stringify(body.error || body.status)});
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error || body.status));
+      cli.error({message:"ERROR encountered: " + JSON.stringify(body.errors || body.error || body.status)});
+      cli.debug({name: '3scale-cli:app-plan:getApplicationPlanByName', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)});
+      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
     } else {
       var plan = _.first(_.filter(body.plans,function(num){ return num.application_plan.name == plan_name;}))
       if(_.isUndefined(plan)){
+        cli.debug({name: '3scale-cli:app-plan:getApplicationPlanByName', msg: 'ERROR: Can\'t find plan with name %o.', data: plan_name});
         return null
       }else{
+        cli.debug({name: '3scale-cli:app-plan:getApplicationPlanByName', msg: 'result: %o' , data: plan.application_plan});
         return plan.application_plan
       }
     }
@@ -99,14 +116,19 @@ exports.listApplicationPlans = function(service_id){
     }
   };
 
+  cli.debug({name: '3scale-cli:app-plan:list', msg: 'API call URL: %o', data: url});
+  cli.debug({name: '3scale-cli:app-plan:list', msg: 'data sent %o: ', data: options.form});
+
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
     var body = JSON.parse(r[0].body);
     if (res.statusCode >= 300) {
-      cli.error({message:"ERROR encountered: " + JSON.stringify(body.error || body.status)});
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error || body.status));
+      cli.error({message:"ERROR encountered: " + JSON.stringify(body.errors || body.error || body.status)});
+      cli.debug({name: '3scale-cli:app-plan:list', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)});
+      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
     } else {
+      cli.debug({name: '3scale-cli:app-plan:list', msg: 'result: %o' , data: body.plans});
       return body.plans
     }
   });
@@ -124,46 +146,38 @@ exports.deleteApplicationPlanById = function(service_id, plan_id){
     }
   };
 
+  cli.debug({name: '3scale-cli:app-plan:deleteApplicationPlanById', msg: 'API call URL: %o', data: url});
+  cli.debug({name: '3scale-cli:app-plan:deleteApplicationPlanById', msg: 'data sent %o: ', data: options.form});
+
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
     if(r[0].body == ''){ //DELETE has no payload unless error encountered
+      cli.debug({name: '3scale-cli:app-plan:deleteApplicationPlanById', msg: 'DELETED'});
       return true
     }else{
       var body = JSON.parse(r[0].body);
-      cli.error({message:"ERROR encountered: " + JSON.stringify(body.error || body.status)});
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error || body.status));
+      cli.error({message:"ERROR encountered: " + JSON.stringify(body.errors || body.error || body.status)});
+      cli.debug({name: '3scale-cli:app-plan:deleteApplicationPlanById', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)});
+      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
     }
   })
 }
 
 exports.deleteApplicationPlanByName = function(service_id, plan_name){
-  var url = config.API+"/services/"+service_id+"/application_plans.json";
-
-  var options ={
-    method: 'GET',
-    url: url,
-    form:{
-      "access_token": config.access_token
+  var that = this;
+  return that.getApplicationPlanByName(service_id, plan_name).then(function(plan){
+    if(plan){
+      return that.deleteApplicationPlanById(service_id, plan.id)
+    }else{
+      return null //no plan found
     }
-  };
-
-  var response = request(options);
-  return response.then(function (r) {
-    var res  = r[0].req.res;
-    var body = JSON.parse(r[0].body);
-    if (res.statusCode >= 300) {
-      cli.error({message:"ERROR encountered: " + JSON.stringify(body.error || body.status)});
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error || body.status));
-    } else {
-      var plan = _.first(_.filter(body.plans,function(num){ return num.application_plan.name == plan_name;}))
-      if(_.isUndefined(plan)){
-        return null
-      }else{
-        return plan.application_plan
-      }
+  }).then(function(result){
+    if(result){
+      cli.debug({name: '3scale-cli:app-plan:deleteApplicationPlanByName', msg: 'DELETED'});
     }
-  });
+    return result
+  })
 }
 
 
