@@ -11,9 +11,13 @@ var _ = require("underscore");
 nconf.file({ file: osHomedir()+"/.3scale/credentials.json" });
 nconf.load();
 
+cli.debug({name: '3scale-cli:config', msg: 'conf file loaded.'})
+
 exports.configure = function(){
   mkdirp(osHomedir()+"/.3scale/", function (err) {  //check if ~/.3scale exists
-      if (err){ console.error(err)
+      if (err){
+        console.error(err)
+        cli.debug({name: '3scale-cli:config', msg: '~/.3scale folder does not exist.'})
       }else {
         cli.print({message:"Please answer the following questions to configure 3scale cli."});
         var questions = [
@@ -48,6 +52,9 @@ exports.configure = function(){
               exports.wildcard = nconf.get("threescale:wildcard");
               exports.API = "https://"+nconf.get("threescale:id")+"-admin."+nconf.get("threescale:wildcard")+"/admin/api";
 
+              cli.debug({name: '3scale-cli:config', msg: 'conf file saved.'})
+              cli.debug({name: '3scale-cli:config', msg: 'Values are: token:'+nconf.get("threescale:access_token")+' id:'+nconf.get("threescale:id")+ ' wildcard:'+nconf.get("threescale:wildcard")})
+
               //check if configuration is valid
               testConfig(function(e, valid){
                 if(valid){
@@ -77,6 +84,7 @@ exports.get = function(key){
 // Make a test call to services endpoint to check if credentials are valid
 var testConfig = function(callback){
   services.listServices().then(function(result){
+    cli.debug({name: '3scale-cli:config', msg: 'Test Config result (show services): %o', data: result})
     if(typeof result.errno != "undefined" || !_.isArray(result)){
       cli.error({message:"ERROR encountered: Your credentials are invalid. Check them and try again."});
       callback( new Error('Credentials invalid'));
