@@ -21,16 +21,17 @@ exports.createMethod = function(service_id, metric_id, friendly_name, unit){
     }
   };
 
-  cli.debug({name: '3scale-cli:methods:create', msg: 'API call URL: '+url+'\n data %o', data: options.form})
+  cli.debug({name: '3scale-cli:methods:create', msg: 'API call URL: %o', data: url})
+  cli.debug({name: '3scale-cli:methods:create', msg: 'data sent %o: ', data: options.form});
 
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
     var body = JSON.parse(r[0].body);
     if (res.statusCode >= 300) {
-      cli.error({message:"ERROR encountered on creating Method: "+r[0].statusCode+" "+ JSON.stringify(body.errors || body.status)});
-      cli.debug({name: '3scale-cli:methods:create', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.status)})
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.status));
+      cli.error({message:"ERROR encountered on creating Method: "+r[0].statusCode+" "+ JSON.stringify(body.errors || body.error || body.status)});
+      cli.debug({name: '3scale-cli:methods:create', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)})
+      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
     } else {
       cli.debug({name: '3scale-cli:methods:create', msg: 'result: %o', data: body.method})
       return body.method;
@@ -49,16 +50,17 @@ exports.listMethods = function(service_id, metric_id){
     }
   };
 
-  cli.debug({name: '3scale-cli:methods:list', msg: 'API call URL: '+url})
+  cli.debug({name: '3scale-cli:methods:list', msg: 'API call URL: %o', data: url});
+  cli.debug({name: '3scale-cli:methods:list', msg: 'data sent %o: ', data: options.form});
 
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
     var body = JSON.parse(r[0].body);
     if (res.statusCode >= 300) {
-      cli.error({message:"ERROR encountered on creating Method: " + JSON.stringify(body.error || body.status)});
-      cli.debug({name: '3scale-cli:methods:list', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.status)})
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error || body.status));
+      cli.error({message:"ERROR encountered on creating Method: " + JSON.stringify(body.errors || body.error || body.status)});
+      cli.debug({name: '3scale-cli:methods:list', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)})
+      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
     } else {
       cli.debug({name: '3scale-cli:methods:list', msg: 'result: %o', data: body.methods})
       return body.methods;
@@ -77,16 +79,17 @@ exports.getMethodById = function(service_id, metric_id, method_id){
     }
   };
 
-  cli.debug({name: '3scale-cli:methods:get', msg: 'API call URL: '+url+'\n data %o', data: options.form})
+  cli.debug({name: '3scale-cli:methods:get', msg: 'API call URL: %o', data: url})
+  cli.debug({name: '3scale-cli:methods:get', msg: 'data sent %o: ', data: options.form});
 
   var response = request(options);
   return response.then(function (r) {
     var res  = r[0].req.res;
     var body = JSON.parse(r[0].body);
     if (res.statusCode >= 300) {
-      cli.error({message:"ERROR encountered on retrieving Method: " + JSON.stringify(body.error || body.status)});
-      cli.debug({name: '3scale-cli:methods:get', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.status)})
-      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error || body.status));
+      cli.error({message:"ERROR encountered on retrieving Method: " + JSON.stringify(body.errors || body.error || body.status)});
+      cli.debug({name: '3scale-cli:methods:get', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)})
+      throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
     } else {
       cli.debug({name: '3scale-cli:methods:get', msg: 'result: %o', data: body.method})
       return body.method;
@@ -113,8 +116,8 @@ exports.updateMethod = function(service_id, metric_id, method_id, friendly_name,
   if(unit)
     options.form["unit"]=unit
 
-
-  cli.debug({name: '3scale-cli:methods:update', msg: 'API call URL: '+url+'\n data %o', data: options.form})
+  cli.debug({name: '3scale-cli:methods:update', msg: 'API call URL: %o', data: url})
+  cli.debug({name: '3scale-cli:methods:update', msg: 'data sent %o: ', data: options.form});
 
   var response = request(options);
   return response.then(function (r) {
@@ -122,7 +125,7 @@ exports.updateMethod = function(service_id, metric_id, method_id, friendly_name,
     var body = JSON.parse(r[0].body);
     if (res.statusCode >= 300) {
       cli.error({message:"ERROR encountered on updating Mapping rule: " + JSON.stringify(body.error)});
-      cli.debug({name: '3scale-cli:methods:update', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.status)})
+      cli.debug({name: '3scale-cli:methods:update', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)})
       throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error));
     } else {
       cli.debug({name: '3scale-cli:methods:update', msg: 'result: %o', data: body.method})
@@ -142,15 +145,20 @@ exports.deleteMethod = function(service_id, metric_id, method_id){
       }
     };
 
+    cli.debug({name: '3scale-cli:methods:delete', msg: 'API call URL: %o', data: url})
+    cli.debug({name: '3scale-cli:methods:delete', msg: 'data sent %o: ', data: options.form});
+
     var response = request(options);
     return response.then(function (r) {
       var res  = r[0].req.res;
       if(r[0].body == ''){ //DELETE has no payload unless error encountered
+        cli.debug({name: '3scale-cli:methods:delete', msg: 'Deleted'})
         return true
       }else{
         var body = JSON.parse(r[0].body);
-        cli.error({message:"ERROR encountered: " + JSON.stringify(body.error || body.status)});
-        throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error || body.status));
+        cli.error({message:"ERROR encountered: " + JSON.stringify(body.errors || body.error || body.status)});
+        cli.debug({name: '3scale-cli:methods:delete', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.error || body.status)})
+        throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.errors || body.error || body.status));
       }
     })
 }
