@@ -27,7 +27,7 @@ var ALLOWED_METHODS = [
 
 var PROMISE_DELAY = 1000 //in ms
 
-exports.import = function(path, service_id, appplan_name, method_pattern){
+exports.import = function(path, service_id, appplan_name, method_pattern, all_methods){
   cli.debug({name:'3scale-cli:swagger', msg:'Inside Swagger import function'})
   SwaggerParser.validate(path)
     .then(function(api) {
@@ -35,6 +35,13 @@ exports.import = function(path, service_id, appplan_name, method_pattern){
         cli.debug({name:'3scale-cli:swagger', msg:'Swagger spec is valid'})
         //List methods to import
         var all_endpoints = extractEndpointsFromSwagger(api, method_pattern)
+
+        if(all_methods && service_id){ //if we import all methods from Swagger
+          METHODS = all_endpoints
+          threescale_water(api, service_id, METHODS);
+          return;
+        }
+
         var questions = [
           {
             type: 'checkbox',
